pub fn get_user_input() -> EmploymentScenarioExpand description
main function to orchestrate user input and create employment scenario struct This function will call the other functions in this module to gather information from the user and create an employment scenario struct based on that information. It will start by getting the payrate and hours worked per week.